==> haskell-ghc-typelits-natnormalise-0.7.8-9-x86_64.pkg.tar.zst: usr/share/haskell/register/haskell-ghc-typelits-natnormalise.sh <==
#!/bin/sh
export PATH='/usr/local/sbin:/usr/local/bin:/usr/bin:/usr/bin/site_perl:/usr/bin/vendor_perl:/usr/bin/core_perl'
echo 'name:                 ghc-typelits-natnormalise
version:              0.7.8
visibility:           public
id:                   ghc-typelits-natnormalise-0.7.8-KqSVYXWXbI4mAC8q6QQCD
key:                  ghc-typelits-natnormalise-0.7.8-KqSVYXWXbI4mAC8q6QQCD
license:              BSD-2-Clause
copyright:
    Copyright © 2015-2016, University of Twente,
    2017-2018, QBayLogic B.V.

maintainer:           christiaan.baaij@gmail.com
author:               Christiaan Baaij
homepage:             http://www.clash-lang.org/
synopsis:             GHC typechecker plugin for types of kind GHC.TypeLits.Nat
description:
    A type checker plugin for GHC that can solve /equalities/ and /inequalities/
    of types of kind @Nat@, where these types are either:

    * Type-level naturals

    * Type variables

    * Applications of the arithmetic expressions @(+,-,*,^)@.

    It solves these equalities by normalising them to /sort-of/ @SOP@
    (Sum-of-Products) form, and then perform a simple syntactic equality.

    For example, this solver can prove the equality between:

    @
    (x + 2)^(y + 2)
    @

    and

    @
    4*x*(2 + x)^y + 4*(2 + x)^y + (2 + x)^y*x^2
    @

    Because the latter is actually the @SOP@ normal form of the former.

    To use the plugin, add the

    @
    OPTIONS_GHC -fplugin GHC.TypeLits.Normalise
    @

    Pragma to the header of your file.

category:             Type System
abi:                  6577883d7f47f40bdfcae71fbc684c52
exposed:              True
exposed-modules:
    GHC.TypeLits.Normalise GHC.TypeLits.Normalise.SOP
    GHC.TypeLits.Normalise.Unify

import-dirs:
    /usr/lib/ghc-9.2.8/site-local/ghc-typelits-natnormalise-0.7.8

library-dirs:
    /usr/lib/ghc-9.2.8/site-local/ghc-typelits-natnormalise-0.7.8

dynamic-library-dirs: /usr/lib
data-dir:             /usr/share/haskell-ghc-typelits-natnormalise
hs-libraries:         HSghc-typelits-natnormalise-0.7.8-KqSVYXWXbI4mAC8q6QQCD
depends:
    base-4.16.4.0 containers-0.6.5.1 ghc-9.2.8 ghc-bignum-1.2
    ghc-tcplugins-extra-0.4.6-9uHiztiXkouG86ImZZc9vs
    transformers-0.5.6.2

haddock-interfaces:
    /usr/share/doc/haskell-ghc-typelits-natnormalise/html/ghc-typelits-natnormalise.haddock

haddock-html:         /usr/share/doc/haskell-ghc-typelits-natnormalise/html
' | '/usr/bin/ghc-pkg-9.2.8' 'update' '--force' '-' '--global' '--no-user-package-db' "$@"

==> haskell-ghc-typelits-natnormalise-0.7.8-10-x86_64.pkg.tar.zst: usr/share/haskell/register/haskell-ghc-typelits-natnormalise.sh <==
#!/bin/sh
export PATH='/usr/local/sbin:/usr/local/bin:/usr/bin:/usr/bin/site_perl:/usr/bin/vendor_perl:/usr/bin/core_perl'
echo 'name:                 ghc-typelits-natnormalise
version:              0.7.8
visibility:           public
id:                   ghc-typelits-natnormalise-0.7.8-KTGNjVDIMPAEtMyv23qgu7
key:                  ghc-typelits-natnormalise-0.7.8-KTGNjVDIMPAEtMyv23qgu7
license:              BSD-2-Clause
copyright:
    Copyright © 2015-2016, University of Twente,
    2017-2018, QBayLogic B.V.

maintainer:           christiaan.baaij@gmail.com
author:               Christiaan Baaij
homepage:             http://www.clash-lang.org/
synopsis:             GHC typechecker plugin for types of kind GHC.TypeLits.Nat
description:
    A type checker plugin for GHC that can solve /equalities/ and /inequalities/
    of types of kind @Nat@, where these types are either:

    * Type-level naturals

    * Type variables

    * Applications of the arithmetic expressions @(+,-,*,^)@.

    It solves these equalities by normalising them to /sort-of/ @SOP@
    (Sum-of-Products) form, and then perform a simple syntactic equality.

    For example, this solver can prove the equality between:

    @
    (x + 2)^(y + 2)
    @

    and

    @
    4*x*(2 + x)^y + 4*(2 + x)^y + (2 + x)^y*x^2
    @

    Because the latter is actually the @SOP@ normal form of the former.

    To use the plugin, add the

    @
    OPTIONS_GHC -fplugin GHC.TypeLits.Normalise
    @

    Pragma to the header of your file.

category:             Type System
abi:                  c3cd625e49eb483e959394d70c26ad68
exposed:              True
exposed-modules:
    GHC.TypeLits.Normalise GHC.TypeLits.Normalise.SOP
    GHC.TypeLits.Normalise.Unify

import-dirs:
    /usr/lib/ghc-9.2.8/site-local/ghc-typelits-natnormalise-0.7.8

library-dirs:
    /usr/lib/ghc-9.2.8/site-local/ghc-typelits-natnormalise-0.7.8

dynamic-library-dirs: /usr/lib
data-dir:             /usr/share/haskell-ghc-typelits-natnormalise
hs-libraries:         HSghc-typelits-natnormalise-0.7.8-KTGNjVDIMPAEtMyv23qgu7
depends:
    base-4.16.4.0 containers-0.6.5.1 ghc-9.2.8 ghc-bignum-1.2
    ghc-tcplugins-extra-0.4.6-9uHiztiXkouG86ImZZc9vs
    transformers-0.5.6.2

haddock-interfaces:
    /usr/share/doc/haskell-ghc-typelits-natnormalise/html/ghc-typelits-natnormalise.haddock

haddock-html:         /usr/share/doc/haskell-ghc-typelits-natnormalise/html
' | '/usr/bin/ghc-pkg-9.2.8' 'update' '--force' '-' '--global' '--no-user-package-db' "$@"
